UnboundedBehavior enum Theming

How the splitter should behave when the main-axis constraints are unbounded.

Inheritance
Available extensions

Values

shrinkToChildren → const UnboundedBehavior

Expand panels using Flex widgets when constraints are unbounded.

useFallbackExtent → const UnboundedBehavior

Constrain the layout using a LimitedBox when constraints are unbounded.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UnboundedBehavior>
A constant List of the values in this enum, in order of their declaration.