onChangeStart property
Called when a drag gesture starts, with the position at that moment - the real request, which may be a pixel pin.
Implementation
final ValueChanged<SplitterChangeDetails>? onChangeStart;
Called when a drag gesture starts, with the position at that moment - the real request, which may be a pixel pin.
final ValueChanged<SplitterChangeDetails>? onChangeStart;